==> prtg-xml-2.0.2-sources.jar: org/adeptnet/prtg/xml/Prtg.java <==

package org.adeptnet.prtg.xml;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.CopyStrategy;
import org.jvnet.jaxb2_commons.lang.CopyTo;
import org.jvnet.jaxb2_commons.lang.JAXBCopyStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for PrtgType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PrtgType">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="result" type="{urn:ietf:params:xml:ns:prtg-1.0}ChannelType" maxOccurs="unbounded"/>
 *         &lt;element name="error" type="{urn:ietf:params:xml:ns:prtg-1.0}BooleanType" minOccurs="0"/>
 *         &lt;element name="text" type="{urn:ietf:params:xml:ns:prtg-1.0}ErrorMessage" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PrtgType", namespace = "urn:ietf:params:xml:ns:prtg-1.0", propOrder = {
    "result",
    "error",
    "errorText"
})
@XmlRootElement(name = "prtg", namespace = "urn:ietf:params:xml:ns:prtg-1.0")
public class Prtg
    implements Serializable, Cloneable, CopyTo, ToString
{

    private final static long serialVersionUID = 201401010001L;
    @XmlElement(namespace = "urn:ietf:params:xml:ns:prtg-1.0", required = true)
    protected List<ChannelType> result;
    @XmlElement(namespace = "urn:ietf:params:xml:ns:prtg-1.0")
    protected BooleanType error;
    @XmlElement(name = "text", namespace = "urn:ietf:params:xml:ns:prtg-1.0")
    protected String errorText;

    /**
     * Gets the value of the result property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the result property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getResult().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChannelType }
     * 
     * 
     */
    public List<ChannelType> getResult() {
        if (result == null) {
            result = new ArrayList<ChannelType>();
        }
        return this.result;
    }

    public boolean isSetResult() {
        return ((this.result!= null)&&(!this.result.isEmpty()));
    }

    public void unsetResult() {
        this.result = null;
    }

    /**
     * Gets the value of the error property.
     * 
     * @return
     *     possible object is
     *     {@link BooleanType }
     *     
     */
    public BooleanType getError() {
        return error;
    }

    /**
     * Sets the value of the error property.
     * 
     * @param value
     *     allowed object is
     *     {@link BooleanType }
     *     
     */
    public void setError(BooleanType value) {
        this.error = value;
    }

    public boolean isSetError() {
        return (this.error!= null);
    }

    /**
     * Gets the value of the errorText property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorText() {
        return errorText;
    }

    /**
     * Sets the value of the errorText property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorText(String value) {
        this.errorText = value;
    }

    public boolean isSetErrorText() {
        return (this.errorText!= null);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        {
            List<ChannelType> theResult;
            theResult = (this.isSetResult()?this.getResult():null);
            strategy.appendField(locator, this, "result", buffer, theResult);
        }
        {
            BooleanType theError;
            theError = this.getError();
            strategy.appendField(locator, this, "error", buffer, theError);
        }
        {
            String theErrorText;
            theErrorText = this.getErrorText();
            strategy.appendField(locator, this, "errorText", buffer, theErrorText);
        }
        return buffer;
    }

    public Prtg withResult(ChannelType... values) {
        if (values!= null) {
            for (ChannelType value: values) {
                getResult().add(value);
            }
        }
        return this;
    }

    public Prtg withResult(Collection<ChannelType> values) {
        if (values!= null) {
            getResult().addAll(values);
        }
        return this;
    }

    public Prtg withError(BooleanType value) {
        setError(value);
        return this;
    }

    public Prtg withErrorText(String value) {
        setErrorText(value);
        return this;
    }

    public Object clone() {
        return copyTo(createNewInstance());
    }

    public Object copyTo(Object target) {
        final CopyStrategy strategy = JAXBCopyStrategy.INSTANCE;
        return copyTo(null, target, strategy);
    }

    public Object copyTo(ObjectLocator locator, Object target, CopyStrategy strategy) {
        final Object draftCopy = ((target == null)?createNewInstance():target);
        if (draftCopy instanceof Prtg) {
            final Prtg copy = ((Prtg) draftCopy);
            if (this.isSetResult()) {
                List<ChannelType> sourceResult;
                sourceResult = (this.isSetResult()?this.getResult():null);
                @SuppressWarnings("unchecked")
                List<ChannelType> copyResult = ((List<ChannelType> ) strategy.copy(LocatorUtils.property(locator, "result", sourceResult), sourceResult));
                copy.unsetResult();
                if (copyResult!= null) {
                    List<ChannelType> uniqueResultl = copy.getResult();
                    uniqueResultl.addAll(copyResult);
                }
            } else {
                copy.unsetResult();
            }
            if (this.isSetError()) {
                BooleanType sourceError;
                sourceError = this.getError();
                BooleanType copyError = ((BooleanType) strategy.copy(LocatorUtils.property(locator, "error", sourceError), sourceError));
                copy.setError(copyError);
            } else {
                copy.error = null;
            }
            if (this.isSetErrorText()) {
                String sourceErrorText;
                sourceErrorText = this.getErrorText();
                String copyErrorText = ((String) strategy.copy(LocatorUtils.property(locator, "errorText", sourceErrorText), sourceErrorText));
                copy.setErrorText(copyErrorText);
            } else {
                copy.errorText = null;
            }
        }
        return draftCopy;
    }

    public Object createNewInstance() {
        return new Prtg();
    }

}

==> prtg-xml-3.0.1-sources.jar: org/adeptnet/prtg/xml/Prtg.java <==

package org.adeptnet.prtg.xml;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for PrtgType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="PrtgType"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="result" type="{http://xml.adeptnet.org/prtg/prtg.xsd}ChannelType" maxOccurs="unbounded"/&gt;
 *         &lt;element name="error" type="{http://xml.adeptnet.org/prtg/prtg.xsd}BooleanType" minOccurs="0"/&gt;
 *         &lt;element name="text" type="{http://xml.adeptnet.org/prtg/prtg.xsd}ErrorMessage" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *       &lt;attribute ref="{http://www.w3.org/XML/1998/namespace}base"/&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "PrtgType", namespace = "http://xml.adeptnet.org/prtg/prtg.xsd", propOrder = {
    "result",
    "error",
    "errorText"
})
@XmlRootElement(name = "prtg")
public class Prtg
    implements Serializable
{

    private final static long serialVersionUID = 201401010001L;
    @XmlElement(required = true)
    protected List<ChannelType> result;
    @XmlSchemaType(name = "string")
    protected BooleanType error;
    @XmlElement(name = "text")
    protected String errorText;
    @XmlAttribute(name = "base", namespace = "http://www.w3.org/XML/1998/namespace")
    @XmlSchemaType(name = "anyURI")
    protected String base;

    /**
     * Gets the value of the result property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the result property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getResult().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link ChannelType }
     * 
     * 
     */
    public List<ChannelType> getResult() {
        if (result == null) {
            result = new ArrayList<ChannelType>();
        }
        return this.result;
    }

    public boolean isSetResult() {
        return ((this.result!= null)&&(!this.result.isEmpty()));
    }

    public void unsetResult() {
        this.result = null;
    }

    /**
     * Gets the value of the error property.
     * 
     * @return
     *     possible object is
     *     {@link BooleanType }
     *     
     */
    public BooleanType getError() {
        return error;
    }

    /**
     * Sets the value of the error property.
     * 
     * @param value
     *     allowed object is
     *     {@link BooleanType }
     *     
     */
    public void setError(BooleanType value) {
        this.error = value;
    }

    public boolean isSetError() {
        return (this.error!= null);
    }

    /**
     * Gets the value of the errorText property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getErrorText() {
        return errorText;
    }

    /**
     * Sets the value of the errorText property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setErrorText(String value) {
        this.errorText = value;
    }

    public boolean isSetErrorText() {
        return (this.errorText!= null);
    }

    /**
     * Gets the value of the base property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBase() {
        return base;
    }

    /**
     * Sets the value of the base property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBase(String value) {
        this.base = value;
    }

    public boolean isSetBase() {
        return (this.base!= null);
    }

}
